@@ -7,7 +7,7 @@ SENTRY_DSN = 'XXX'
 FLOAT_PROJECT_TOKEN = 'XXXX'
 SAMPLES_PROJECT_TOKEN = 'XXX'
 LABML_VERSION = 'XXX'
-IS_MIX_PANEL = False
+ANALYTICS_TO_SERVER = False
 IS_LOCAL_SETUP = True
 INDICATOR_LIMIT = 100
 IS_LOGIN_REQUIRED = True
